from django.conf.urls.defaults import *
from django.contrib import admin

admin.autodiscover()

urlpatterns = patterns('',
    url(r'^admin/', include(admin.site.urls)),
    url(r'^$', 'djangodblog.tests.views.raise_exc', name='dblog-raise-exc'),
    url(r'', include('djangodblog.urls')),
)


from django.conf import settings
from django.conf.urls.defaults import *
from django.utils.hashcompat import md5_constructor

from feeds import ErrorFeed, SummaryFeed

hashed_secret = md5_constructor(settings.SECRET_KEY).hexdigest()

urlpatterns = patterns('',
    url(r'feeds/%s/messages.xml' % hashed_secret, ErrorFeed(), name='dblog-feed-messages'),
    url(r'feeds/%s/summaries.xml' % hashed_secret, SummaryFeed(), name='dblog-feed-summaries'),
)
